.. Copyright (C) 2015-2017 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2015-2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

`PostgreSQL`__ is a popular relational open source database. This role can be
used to install and manage a set of PostgreSQL clusters on Debian-based
systems. You can use :ref:`debops.postgresql` role to configure roles and
databases on local or remote PostgreSQL servers.

.. __: https://www.postgresql.org/
